% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PapaDiv_func_20170924.R
\name{PapaDiv}
\alias{PapaDiv}
\title{PapaDiv() function}
\usage{
PapaDiv(parents_table, seq_table, path_out)
}
\arguments{
\item{parents_table}{is a table containing the sample names of the parents in
each nest. This table should be organized so that each row represents one
nest, with the individual names of the mothers in the first column
(Mother), and the individual names of the fathers in the second column
(Father).}

\item{seq_table}{seq_table is a sequence table as output by the 'dada2'
pipeline, which has samples in rows and nucleotide sequence variants in
columns.}

\item{path_out}{is a user defined path to the folder where the output files
will be saved.}
}
\value{
a set of R lists containing for the joint diversity of each parent
  pair, the proportion of sequences that are shared between the parents, the
  diversity of each of the parents, the observed sequence variants in each
  parent, the matched sequence variants, and the incongruent sequence
  variants in each parent. The sequences are named in the output by an index
  number corresponding to their column number in the sequence table, thus
  identical sequences will have identical sample names in all the output
  files. These files are saved in a sub folder in the output path called
  Parent_pairs (created by PapaDiv()) and can be reopened in R using the
  list.load() function in the 'rlist' package. For downstream data analysis,
  the PapaDiv() function also produces a summary table with the names of the
  parents in a pair, their respective MHC diversities, and the joint parent
  pair diversity. This table is saved as a .csv file in the output path.
}
\description{
\code{\link{PapaDiv}} calculates the joint major histocompatibility complex
(MHC) diversity in parent pairs, taking into account alleles that are shared
between the parents. The joint diversity in parent pairs is useful for
heritability analyses in non-model species, where one wants to estimate the
heritability of MHC diversity. The number of unique alleles in offspring may
not be directly derived from the parental genotypes if some alleles are
shared between the parents.
}
\examples{
parents_table <- parents_table
seq_table <- sequence_table
path_out <- tempdir()
PapaDiv(parents_table, seq_table, path_out)
}
\seealso{
For more information about 'dada2' visit
  <https://benjjneb.github.io/dada2>
}
